@@ -1,7 +1,5 @@
 package Bot::BasicBot::Pluggable::Module::Karma;
-{
-  $Bot::BasicBot::Pluggable::Module::Karma::VERSION = '0.97';
-}
+$Bot::BasicBot::Pluggable::Module::Karma::VERSION = '1.00';
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
@@ -40,7 +38,7 @@ sub told {
     my $op_re      = qr{ ( \-\- | \+\+ )        }x;
     my $comment_re = qr{ (?: \s* \# \s* (.+) )? }x;
     for my $regex (
-        qr{^   (\w+)     $op_re $comment_re  }x, # singleword++
+        qr{^   (\S+)     $op_re $comment_re  }x, # singleword++
         qr{^ \( (.+)  \) $op_re $comment_re  }x  # (more words)++
     ) {
         if (my($thing, $op, $comment) = $body =~ $regex) {
@@ -164,7 +162,7 @@ sub add_karma {
     my @changes = @{ $self->get("karma_$thing") || [] };
     push @changes, $row;
     $self->set( "karma_$thing" => \@changes );
-    my $respond = $self->get("karma_change_reponse");
+    my $respond = $self->get('user_karma_change_response');
     $respond = 1 if !defined $respond;
     return $respond ?
         "Karma for $thing is now " . scalar $self->get_karma($thing) : 1;
@@ -207,7 +205,7 @@ Bot::BasicBot::Pluggable::Module::Karma - tracks karma for various concepts
 
 =head1 VERSION
 
-version 0.97
+version 1.00
 
 =head1 IRC USAGE
 
@@ -288,8 +286,6 @@ explanations.
 Defaults to 1; whether to randomize the order of reasons. If set
 to 0, the reasons are sorted in reversed chronological order.
 
-=back
-
 =item karma_change_response
 
 Defaults to 1; whether to show a response when the karma of a
@@ -297,6 +293,8 @@ thing is changed.  If true, the bot will reply with the new karma.
 If set to 0, the bot will silently update the karma, without
 a response.
 
+=back
+
 =head1 AUTHOR
 
 Mario Domgoergen <mdom@cpan.org>
